@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 sub new {
     my $class = shift;
@@ -108,13 +108,7 @@ sub _parent {
                 $self->nick( $self->{nick} . '_' );
             }
             elsif ( $line =~ /^:\S+\s001\s/ ) {
-                if ( $self->{connect}{join} ) {
-                    $self->say("JOIN $_") for (
-                        ( ref $self->{connect}{join} eq 'ARRAY' )
-                            ? @{ $self->{connect}{join} }
-                            : $self->{connect}{join}
-                    );
-                }
+                $self->join;
                 $session->{established} = 1;
                 alarm 1 if ( @{ $self->{ticks} } );
             }
@@ -151,6 +145,9 @@ sub _on_message {
         elsif ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s(\S+)\s(.*)/ ) {
             @{ $self->{in} }{ qw( nick user server command forum text ) } = ( $1, $2, $3, $4, $5, $6 );
         }
+        elsif ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s(\S+)/ ) {
+            @{ $self->{in} }{ qw( nick user server command forum ) } = ( $1, $2, $3, $4, $5, $6 );
+        }
         elsif ( $line =~ /^(PING)\s(.+)/ ) {
             @{ $self->{in} }{ qw( command text ) } = ( $1, $2 );
             $self->say( 'PONG ' . $self->{in}{text} );
@@ -225,24 +222,28 @@ sub load {
 
     for my $plugin (@_) {
         unless ( ref $plugin ) {
-            my $namespace;
-
-            eval 'require ' . __PACKAGE__ . "::$plugin";
-            unless ($@) {
-                $namespace = __PACKAGE__ . "::$plugin";
+            if ( $plugin =~ /^:core$/i ) {
+                $self->load( qw( Join ) );
+                next;
             }
-            else {
-                croak($@) unless ( $@ =~ /^Can't locate/ );
 
-                eval "require $plugin";
+            my $namespace;
+            for (
+                $plugin,
+                __PACKAGE__ . "::Y::$plugin",
+                __PACKAGE__ . "::X::$plugin",
+                __PACKAGE__ . "::$plugin",
+            ) {
+                eval "require $_";
                 unless ($@) {
-                    $namespace = $plugin;
+                    $namespace = $_;
+                    last;
                 }
                 else {
                     croak($@) unless ( $@ =~ /^Can't locate/ );
-                    croak("Unable to find or properly load $plugin");
                 }
             }
+            croak("Unable to find or properly load $plugin") unless ($namespace);
 
             next if ( $self->{loaded}{$namespace} );
 
@@ -381,6 +382,53 @@ sub nick {
     return $self->{nick};
 }
 
+sub join {
+    my $self = shift;
+
+    my @join = @{ ( $self->can('store') ) ? $self->store->get('join') || [] : [] };
+
+    unless (@_) {
+        if (@join) {
+            $self->say("JOIN $_") for (@join);
+        }
+        elsif ( $self->{connect}{join} ) {
+            for (
+                ( ref $self->{connect}{join} eq 'ARRAY' )
+                    ? @{ $self->{connect}{join} }
+                    : $self->{connect}{join}
+            ) {
+                push( @join, $_ );
+                $self->say("JOIN $_");
+            }
+        }
+    }
+    else {
+        for (@_) {
+            push( @join, $_ );
+            $self->say("JOIN $_");
+        }
+    }
+
+    $self->store->set( 'join' => \@join ) if ( $self->can('store') );
+
+    return $self;
+}
+
+sub part {
+    my $self = shift;
+
+    my @join = @{ ( $self->can('store') ) ? $self->store->get('join') || [] : [] };
+
+    for my $channel (@_) {
+        $self->say("PART $channel");
+        @join = grep { $_ ne $channel } @join;
+    }
+
+    $self->store->set( 'join' => \@join ) if ( $self->can('store') );
+
+    return $self;
+}
+
 1;
 
 __END__
@@ -395,7 +443,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -578,19 +626,26 @@ provided as a sub-class of itself. Then it will look for the plugin under the
 assumption you provided it's full name.
 
     plugins => [
-        'Store',               # matches "Bot::IRC::Store"
-        'Bot::IRC::X::Random', # matches "Bot::IRC::X::Random"
-        'My::Own::Plugin',     # matches "My::Own::Plugin"
+        'Store',           # matches "Bot::IRC::Store"
+        'Random',          # matches "Bot::IRC::X::Random"
+        'Thing',           # matches "Bot::IRC::Y::Thing"
+        'My::Own::Plugin', # matches "My::Own::Plugin"
     ],
 
 An unenforced convention for public/shared plugins is to have non-core plugins
 (all plugins not provided directly by this CPAN library) subclasses of
 "Bot::IRC::X". For private/unshared plugins, you can specify whatever name you
-want, but maybe consider something like "Bot::IRC::Y".
+want, but maybe consider something like "Bot::IRC::Y". Plugins set in the X or
+Y subclass namespaces will get matched just like core plugins. "Y" plugins will
+have precedence over "X" which in turn will have precedence over core.
 
 If you need to allow for variables to get passed to your plugins, an unenforced
 convention is to do so via the C<vars> key to C<new()>.
 
+If you specify ":core" as a plugin name, it will be expanded to load all the
+core plugins. (Core plugins are all the plugins that are bundled and
+distributed with L<Bot::IRC>.)
+
 =head1 PLUGIN METHODS
 
 The following are methods available from this class related to plugins.
@@ -859,6 +914,24 @@ string that's a properly IRC message.
 Use C<nick> to change the bot's nick. If the nick is already in use, the bot
 will try appending "_" to it until it finds an open nick.
 
+=head2 join
+
+Use C<join()> to join channels.
+
+    $bot->join('#help');
+
+If some sort of persistent storage plugin is loaded, the bot will remember the
+channels it has joined or parted and use that as it's initial join on restart.
+
+=head2 part
+
+Use C<part()> to part channels.
+
+    $bot->part('#help');
+
+If some sort of persistent storage plugin is loaded, the bot will remember the
+channels it has joined or parted and use that as it's initial join on restart.
+
 =head1 SEE ALSO
 
 You can look for additional information at:
